@@ -125,11 +125,8 @@ static int cleanupSockClose (int fd)
 }
 
 #ifdef KERBEROS_V4
-static int kerberos_auth(socket, canonical, principal) 
+static int kerberos_auth(int socket, char *canonical, char *principal) 
 /* authenticate to the server host using Kerberos V4 */
-int socket;		/* socket to server host */
-char *canonical;	/* server name */
-char *principal;
 {
     KTEXT ticket;
     MSG_DAT msg_data;
@@ -188,10 +185,8 @@ char *principal;
 #endif /* KERBEROS_V4 */
 
 #ifdef KERBEROS_V5
-static int kerberos5_auth(socket, canonical)
+static int kerberos5_auth(int socket, const char *canonical)
 /* authenticate to the server host using Kerberos V5 */
-int socket;             /* socket to server host */
-const char *canonical;  /* server name */
 {
     krb5_error_code retval;
     krb5_context context;
@@ -399,9 +394,12 @@ static void mark_oversized(struct query *ctl, int size)
     cnt = current ? current->val.status.num : 0;
 
     /* if entry exists, increment the count */
-    if (current && (tmp = str_in_list(&current, sizestr, FALSE)))
-    {
-	tmp->val.status.mark++;
+    if (current)  {
+        tmp = str_in_list(&current, sizestr, FALSE);
+        if (tmp)
+        {
+	    tmp->val.status.mark++;
+        }
     }
     /* otherwise, create a new entry */
     /* initialise with current poll count */
@@ -804,8 +802,9 @@ flagthemail:
 	     * To avoid flooding the logs when using --keep, report
 	     * skipping of new messages only.
 	     */
-	    if (outlevel > O_SILENT && msgcode != MSGLEN_OLD)
-	    report_complete(stdout, GT_(" not flushed\n"));
+	    if (outlevel > O_SILENT && msgcode != MSGLEN_OLD) {
+                report_complete(stdout, GT_(" not flushed\n"));
+            }
 
 	    /* maybe we mark this message as seen now? */
 	    if (ctl->server.base_protocol->mark_seen
