@@ -193,6 +193,24 @@ static void reportquerystatus(FILE *fp) {
 
 const char *iana_charset;
 
+/**
+ * @brief check time_t sanity and log a warning 10 years before Y2038 becomes a problem.
+ *
+ * Just in case someone tries to run this in a computer museum and forgets stuffing
+ * things in a time machine.
+ */
+static void y2038_check_or_warn(void)
+{
+        const int epoch_ts_2028_01_01 = 1830297600 / 2;  /* 2028-01-01T00:00Z */
+        time_t t;
+        errno = 0;
+        if (time(&t) == (time_t)-1 && errno == EOVERFLOW) {
+                report(stderr, GT_("%s: WARNING: time() overflowed. Proper function is not guaranteed. Obtain an operating system which supports operation beyond the year 2038.\n"), program_name);
+        } else if (sizeof(time_t) < 8 && (time_t)-1 < 0 && time(NULL) >= epoch_ts_2028_01_01) { // four-byte time_t and time_t is signed} -> start warning 10 years before time
+                report(stderr, GT_("%s: WARNING: the operation system this program was built for does not function beyond the year 2038. Plan your update accordingly.\n"), program_name);
+        }
+}
+
 int main(int argc, char **argv)
 {
     int bkgd = FALSE;
@@ -203,7 +221,7 @@ int main(int argc, char **argv)
     char *netrc_file; /** long-lived variable containing the name of the .netrc path */
     char *tmpbuf;
     pid_t pid;
-    int lastsig = 0;
+    lastsig = 0;
 
 #if defined(__FreeBSD__) && defined(__FreeBSD_USE_KVM)
     dropprivs();
@@ -424,6 +442,8 @@ int main(int argc, char **argv)
     else
 	report_init((run.poll_interval == 0 || nodetach) && !run.logfile); /* when changing this, change copy above, too */
 
+    y2038_check_or_warn(); // this goes between initialization of logging and before we're getting serious
+
 #ifdef POP3_ENABLE
     /* initialize UID handling */
     {
@@ -958,7 +978,8 @@ int main(int argc, char **argv)
 	     * unwedge all servers in case the problem has been
 	     * manually repaired.
 	     */
-	    if ((lastsig = interruptible_idle(run.poll_interval)))
+            lastsig = interruptible_idle(run.poll_interval);
+	    if (lastsig)
 	    {
 		if (outlevel > O_SILENT)
 #ifdef HAVE_STRSIGNAL
@@ -1255,8 +1276,8 @@ static int load_params(int argc, char **argv, int optind)
     if (cmd_run.use_syslog)
 	run.use_syslog = (cmd_run.use_syslog == FLAG_TRUE);
     if (cmd_run.postmaster) {
-    	free((void *)run.postmaster);
-	run.postmaster = cmd_run.postmaster;
+	xfree(run.postmaster);
+	run.postmaster = xstrdup(cmd_run.postmaster);
     }
     if (cmd_run.bouncemail)
 	run.bouncemail = (cmd_run.bouncemail == FLAG_TRUE);
@@ -1506,9 +1527,9 @@ static int load_params(int argc, char **argv, int optind)
     if (!run.postmaster)
     {
 	if (getuid() != ROOT_UID)		/* ordinary user */
-	    run.postmaster = user;
+	    run.postmaster = xstrdup(user);
 	else					/* root */
-	    run.postmaster = "postmaster";
+	    run.postmaster = xstrdup("postmaster");
     }
 
     if (st) {
