@@ -165,7 +165,7 @@ struct runctl
     char	*logfile;	/** where to write log information */
     char	*idfile;	/** where to store UID data */
     char	*pidfile;	/** where to record the PID of daemon mode processes */
-    const char	*postmaster;
+    char	*postmaster;
     char	*properties;
     int		poll_interval;	/** poll interval in seconds (daemon mode, 0 == off) */
     flag	bouncemail;
@@ -255,7 +255,7 @@ struct hostdata		/* shared among all user connections to given server */
     struct idlist *akalist;		/* server name first, then akas */
     struct idlist *localdomains;	/* list of pass-through domains */
     int protocol;			/* protocol type */
-    const char *service;		/* service name */
+    char *service;			/* service name */
     int interval;			/* # cycles to skip between polls */
     int authenticate;			/* authentication mode to try */
     int timeout;			/* inactivity timout in seconds */
@@ -325,7 +325,7 @@ struct query
     char *smtpaddress;		/* address to force in RCPT TO */ 
     char *smtpname;             /* full RCPT TO name, including domain */
     struct idlist *antispam;	/* list of listener's antispam response */
-    const char *mda;		/* local MDA to pass mail to */
+    char *mda;			/* local MDA to pass mail to */
     char *bsmtp;		/* BSMTP output file */
     char listener;		/* what's the listener's wire protocol? */
 #define SMTP_MODE	'S'
@@ -681,7 +681,7 @@ void fm_clearpassword(void);
 struct addrinfo; // forward declaration JIC
 
 void escapes(const char *, char *);
-char *visbuf(const char *str); /**< prints str escaped. Returns pointer to malloc()d buffer, which can be released with zap_free_visbuf */
+char *visbuf(const char *str); /**< prints str escaped. Returns pointer to malloc()d buffer, which can be released with clear_free_visbuf */
 void clear_free_visbuf(void); /**< clears then releases static buffer used by visbuf */
 const char *showproto(int);
 void dump_config(struct runctl *runp, struct query *querylist);
@@ -777,4 +777,10 @@ int match_regex(const char *restrict regexpattern, const char *restrict ins);
 
 #define	NETRC_FILE	".netrc"
 
+#define ASSERT(x) do { \
+        if (!(x)) { \
+                report(stderr, "\nASSERT(%s) failed in %s at %s:%u, aborting!\n", #x, __func__, __FILE__, (unsigned int)__LINE__); \
+                abort(); \
+        }} while(0)
+
 /* fetchmail.h ends here */
