@@ -103,8 +103,6 @@ static void copy_capabilities(const char *buf)
      */
     if (has_idle == FALSE && strstr(capabilities, "IDLE"))
        has_idle = TRUE;
-    if (outlevel >= O_VERBOSE)
-       report(stdout, GT_("will idle after poll\n")); /* FIXME: rename this to can... idle for next release */
 
     peek_capable = (imap_version >= IMAP4);
 }
@@ -437,7 +435,9 @@ static int do_auth_external (int sock, const char *command, const char *name)
      */
     char buf[256];
 
-    if (!strstr(capabilities, "SASL-IR")) {
+    if (!strstr(capabilities, "SASL-IR") && !strstr(capabilities, "SASL_IR")) {
+	/* Cyrus IMAP 3.10 and newer advertise SASL_IR, which appears to be
+	 * a typo.  https://github.com/cyrusimap/cyrus-imapd/issues/5481 */
 	report(stderr, GT_("server did not advertise SASL-IR extension but fetchmail's implementation requires it for AUTHENTICATE EXTERNAL\n"));
 	return PS_AUTHFAIL;
     }
@@ -482,6 +482,10 @@ static int imap_getauth(int sock, struct query *ctl, char *greeting)
     if (has_idle == FALSE && ctl->forceidle)
         has_idle = TRUE;
 
+    if (ctl->idle && has_idle && outlevel >= O_VERBOSE) {
+            report(stdout, GT_("will idle after poll\n")); /* FIXME: rename this to can... idle for next release */
+    }
+
     commonname = ctl->server.pollname;
     if (ctl->server.via)
 	commonname = ctl->server.via;
@@ -726,7 +730,7 @@ static int imap_getauth(int sock, struct query *ctl, char *greeting)
 	    pwl = 2 * strlen(ctl->password) + 1;
 	    if (remotename) xfree(remotename);
 	    remotename = (char *)xmalloc(rnl);
-	    if (password) xfree(password);
+	    if (password) xzerofree(password);
 	    password = (char *)xmalloc(pwl);
 
 	    imap_canonicalize(remotename, ctl->remotename, rnl);
@@ -734,10 +738,8 @@ static int imap_getauth(int sock, struct query *ctl, char *greeting)
 
 	    snprintf(shroud, sizeof (shroud), "\"%s\"", password);
 	    ok = gen_transact(sock, "LOGIN \"%s\" \"%s\"", remotename, password);
-	    memset(shroud, 0x55, sizeof(shroud));
-	    shroud[0] = '\0';
-	    memset(password, 0x55, strlen(password));
-	    xfree(password);
+	    fm_safe_clearmem(shroud, sizeof(shroud));
+	    xzerofree(password);
 	    xfree(remotename);
 	    return ok; /* this assumes that password is the last authentication method to try */
 	}
@@ -975,7 +977,7 @@ static int imap_getrange(int sock,
 	 *
 	 * this is a while loop because imap_idle() might return on other
 	 * mailbox changes also */
-	while (recentcount == 0 && ctl->idle && has_idle) {
+	while (recentcount == 0 && ctl->idle) {
 	    smtp_close(ctl, 1);
 	    ok = imap_idle(sock, ctl->server.idle_timeout);
 	    if (ok)
@@ -1032,7 +1034,7 @@ static int imap_getrange(int sock,
 					count), count);
 	}
 
-	if (count == 0 && ctl->idle && has_idle)
+	if (count == 0 && ctl->idle)
 	{
 	    /* no messages?  then we may need to idle until we get some */
 	    while (count == 0) {
