@@ -119,6 +119,7 @@ static const struct option longoptions[] = {
 
   {"folder",	required_argument, (int *) 0, 'r' },
   {"smtphost",	required_argument, (int *) 0, 'S' },
+  {"smtphosts",	required_argument, (int *) 0, 'S' },
   {"fetchdomains",	required_argument, (int *) 0, LA_FETCHDOMAINS },
   {"smtpaddress", required_argument, (int *) 0, 'D' },
   {"smtpname",	required_argument, (int *) 0, LA_SMTPNAME },
@@ -269,6 +270,7 @@ int parsecmdline (int argc /** argument count */,
 	    quitind = optind;
 	    break;
 	case 'L':
+	    xfree(rctl->logfile);
 	    rctl->logfile = prependdir (optarg, currentwd);
 	    break;
 	case LA_INVISIBLE:
@@ -282,13 +284,16 @@ int parsecmdline (int argc /** argument count */,
 	    rcfile = prependdir (optarg, currentwd);
 	    break;
 	case 'i':
+	    xfree(rctl->idfile);
 	    rctl->idfile = prependdir (optarg, currentwd);
 	    break;
 	case LA_PIDFILE:
+	    xfree(rctl->pidfile);
 	    rctl->pidfile = prependdir (optarg, currentwd);
 	    break;
 	case LA_POSTMASTER:
-	    rctl->postmaster = (char *) xstrdup(optarg);
+	    xfree(rctl->postmaster);
+	    rctl->postmaster = xstrdup(optarg);
 	    break;
 	case LA_NOBOUNCE:
 	    rctl->bouncemail = FLAG_FALSE;
@@ -332,6 +337,7 @@ int parsecmdline (int argc /** argument count */,
 	    else if (strcasecmp(optarg,"kpop") == 0)
 	    {
 		ctl->server.protocol = P_POP3;
+		xfree(ctl->server.service);
 		ctl->server.service = xstrdup(KPOP_PORT);
 #ifdef KERBEROS_V5
 		ctl->server.authenticate =  A_KERBEROS_V5;
@@ -360,7 +366,8 @@ int parsecmdline (int argc /** argument count */,
 	    ctl->forceidle = FLAG_TRUE;
 	    break;
 	case 'P':
-	    ctl->server.service = optarg;
+	    xfree(ctl->server.service);
+	    ctl->server.service = xstrdup(optarg);
 	    break;
 	case LA_AUTH:
 	    if (strcmp(optarg, "password") == 0)
@@ -406,13 +413,16 @@ int parsecmdline (int argc /** argument count */,
 		ctl->server.timeout = -1;
 	    break;
 	case 'E':
+	    xfree(ctl->server.envelope);
 	    ctl->server.envelope = xstrdup(optarg);
 	    break;
 	case 'Q':    
+	    xfree(ctl->server.qvirtual);
 	    ctl->server.qvirtual = xstrdup(optarg);
 	    break;
 
 	case 'u':
+	    xfree(ctl->remotename);
 	    ctl->remotename = xstrdup(optarg);
 	    break;
 	case 'a':
@@ -466,9 +476,11 @@ int parsecmdline (int argc /** argument count */,
 	    free(buf);
 	    break;
 	case 'D':
+	    xfree(ctl->smtpaddress);
 	    ctl->smtpaddress = xstrdup(optarg);
 	    break;
 	case LA_SMTPNAME:
+	    xfree(ctl->smtpname);
 	  ctl->smtpname = xstrdup(optarg);
 	  break;
 	case 'Z':
@@ -503,10 +515,12 @@ int parsecmdline (int argc /** argument count */,
 	    ctl->expunge = NUM_VALUE_IN(c);
 	    break;
 	case 'm':
+	    xfree(ctl->mda);
 	    ctl->mda = xstrdup(optarg);
 	    ocount++;
 	    break;
 	case LA_BSMTP:
+	    xfree(ctl->bsmtp);
 	    ctl->bsmtp = prependdir (optarg, currentwd);
 	    ocount++;
 	    break;
@@ -519,13 +533,16 @@ int parsecmdline (int argc /** argument count */,
 	    interface_parse(optarg, &ctl->server);
 	    break;
 	case 'M':
+	    xfree(ctl->server.monitor);
 	    ctl->server.monitor = xstrdup(optarg);
 	    break;
 #endif /* CAN_MONITOR */
 	case LA_PLUGIN:
+	    xfree(ctl->server.plugin);
 	    ctl->server.plugin = xstrdup(optarg);
 	    break;
 	case LA_PLUGOUT:
+	    xfree(ctl->server.plugout);
 	    ctl->server.plugout = xstrdup(optarg);
 	    break;
 
@@ -539,14 +556,17 @@ int parsecmdline (int argc /** argument count */,
 	    break;
 
 	case LA_SSLKEY:
+	    xfree(ctl->sslkey);
 	    ctl->sslkey = prependdir (optarg, currentwd);
 	    break;
 
 	case LA_SSLCERT:
+	    xfree(ctl->sslcert);
 	    ctl->sslcert = prependdir (optarg, currentwd);
 	    break;
 
 	case LA_SSLPROTO:
+	    xfree(ctl->sslproto);
 	    ctl->sslproto = xstrdup(optarg);
 	    break;
 
@@ -559,23 +579,28 @@ int parsecmdline (int argc /** argument count */,
 	    break;
 
 	case LA_SSLCERTFILE:
+	    xfree(ctl->sslcertfile);
 	    ctl->sslcertfile = prependdir(optarg, currentwd);
 	    break;
 
 	case LA_SSLCERTPATH:
+	    xfree(ctl->sslcertpath);
 	    ctl->sslcertpath = prependdir(optarg, currentwd);
 	    break;
 
 	case LA_SSLCOMMONNAME:
+	    xfree(ctl->sslcommonname);
 	    ctl->sslcommonname = xstrdup(optarg);
 	    break;
 
 	case LA_SSLFINGERPRINT:
+	    xfree(ctl->sslfingerprint);
 	    ctl->sslfingerprint = xstrdup(optarg);
 	    break;
 #endif
 
 	case LA_PRINCIPAL:
+	    xfree(ctl->server.principal);
 	    ctl->server.principal = xstrdup(optarg);
 	    break;
 
@@ -611,6 +636,7 @@ int parsecmdline (int argc /** argument count */,
 	    break;
 
 	case LA_MOVETO:
+	    xfree(ctl->moveto);
 	    ctl->moveto = xstrdup(optarg);
 	    break;
 
