@@ -1342,10 +1342,8 @@ int close_sink(struct query *ctl, struct msgblk *msg, flag forward)
 	/* close the delivery pipe, we'll reopen before next message */
 	if (sinkfp)
 	{
-	    if (ferror(sinkfp))
-		err = 1, e2 = errno;
-	    if ((fflush(sinkfp)))
-		err = 1, e2 = errno;
+	    if (ferror(sinkfp)) { err = 1; e2 = errno; }
+	    if (fflush(sinkfp)) { err = 1; e2 = errno; }
 
 	    errno = 0;
 	    rc = pclose(sinkfp);
