@@ -443,7 +443,6 @@ enum { SSL_min_security_level = 2 };
 #define DO_SSL_VERSION_CHECK 1
 #ifdef LIBRESSL_VERSION_NUMBER
 # ifdef __OpenBSD__
-#  pragma message "WARNING - Linking against LibreSSL, which is not a supported configuration."
 #  define TLSprovider "LibreSSL(OpenBSD)"
 #  undef  DO_SSL_VERSION_CHECK
 #  define DO_SSL_VERSION_CHECK 0
@@ -637,7 +636,10 @@ ssize_t SockRead(int sock, char *buf, size_t len)
 		/* Matthias Andree: SSL_read can return 0, in that case
 		 * we must call SSL_get_error to figure if there was
 		 * an error or just a "no data" condition */
-		// OpenSSL 3 documents "Old documentation indicated a difference between 0 and -1, and that -1 was retryable. You should instead call SSL_get_error() to find out if it's retryable."
+		// OpenSSL 3 documents "Old documentation indicated a difference between 0 and -1, and that -1 was retryable.
+                // You should instead call SSL_get_error() to find out if it's retryable."
+                // However, we've set auto retry mode on the SSL_CTX so we needn't care about the
+                // SSL_ERROR_WANT_READ SSL_ERROR_WANT_WRITE return codes.
 		ERR_clear_error();
 		if ((n = SSL_read(ssl, bp, (int)n)) <= 0) {
 			e = SSL_get_error(ssl, (int)n);
